@@ -1,9 +1,8 @@
 
 /*
- *  autogen.h
- *  $Id: 851456692b738b0ee9c943bbba6f5c2b9fd7fe43 $
+ *  \file autogen.h
  *
- *  Time-stamp:        "2010-02-24 14:50:07 bkorb"
+ *  Time-stamp:        "2010-07-24 09:03:33 bkorb"
  *
  *  Global header file for AutoGen
  *
@@ -185,7 +184,7 @@ struct macro_desc {
 
     uintptr_t   ozName;    /* macro name (sometimes) */
     uintptr_t   ozText;    /* associated text        */
-    long        res;       /* some sort of result    */
+    uintptr_t   res;       /* some sort of result    */
     void*       funcPrivate;
 };
 
@@ -260,6 +259,7 @@ struct outSpec {
 #define FPF_NOUNLINK   0x0004   /* do not unlink file      */
 #define FPF_STATIC_NM  0x0008   /* name statically alloced */
 #define FPF_NOCHMOD    0x0010   /* do not chmod(2) file    */
+#define FPF_TEMPFILE   0x0020   /* the file is a temp      */
 
 struct fpStack {
     int         flags;
@@ -303,6 +303,18 @@ typedef struct {
 #define _MkStr(_s) #_s
 #define MK_STR(_s) _MkStr(_s)
 
+typedef struct {
+    int          line;
+    char const * file;
+    char const * text;
+} file_line_t;
+
+#define SCM_EVAL_CONST(_s) \
+    do { static file_line_t const fl = { __LINE__, __FILE__, _s }; \
+        pzLastScheme = fl.text; \
+        ag_scm_c_eval_string_from_file_line(fl.text, fl.file, fl.line); \
+    } while (0)
+
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  *
  *  GLOBAL VARIABLES
@@ -318,7 +330,14 @@ MODE tCC*        pzOopsPrefix     VALUE( "" );
  *  Template Processing Globals
  */
 MODE tCC*        pzCurSfx         VALUE( NULL );
+/**
+ * The time to set for the modification times of the output files.
+ */
 MODE time_t      outTime          VALUE( 0 );
+/**
+ * The original time autogen started
+ */
+MODE time_t      startTime        VALUE( 0 );
 MODE tFpStack*   pCurFp           VALUE( NULL );
 MODE tOutSpec*   pOutSpecList     VALUE( NULL );
 MODE jmp_buf     fileAbort;
@@ -326,6 +345,30 @@ MODE char*       pzCurStart       VALUE( NULL );
 MODE uintptr_t   curStartOff      VALUE( 0 );
 MODE tForInfo    forInfo          VALUE( { 0 } );
 MODE FILE*       pfTrace          VALUE( NULL );
+/**
+ * dependency file file pointer.
+ */
+MODE FILE*       pfDepends        VALUE( NULL );
+/**
+ * name of target of rule
+ */
+MODE char const* pzDepTarget      VALUE( NULL );
+/**
+ * name of dependency file
+ */
+MODE char const* pzDepFile        VALUE( NULL );
+/**
+ * base name of both source and derived files.
+ * Either "_TList" or "_SList" gets put on the end.
+ */
+MODE char const* pz_targ_base     VALUE( NULL );
+/**
+ * The actual list of input (source) files.
+ */
+MODE char const* pzSourceList     VALUE( NULL );
+MODE size_t      source_size      VALUE( 0 );
+MODE size_t      source_used      VALUE( 0 );
+MODE ag_bool     dep_phonies      VALUE( AG_FALSE );
 MODE char*       pzTmpStderr      VALUE( NULL );
 
 MODE tCC*        serverArgs[2]    VALUE( { NULL } );
@@ -400,37 +443,40 @@ MODE tDefEntry*  pCurrentEntry    VALUE( NULL );
  *
  *  GLOBAL STRINGS
  */
-#define MKSTRING( name, val ) \
-        MODE char const z ## name[ sizeof( val )] VALUE( val )
+#define MKSTRING(_n, _v) \
+        MODE char const z ## _n[sizeof(_v)] VALUE(_v)
 
-MKSTRING( AllocWhat,  "Could not allocate a %d byte %s\n" );
-MKSTRING( AllocErr,   "Allocation Failure" );
-MKSTRING( Cannot,     "fserr %d: cannot %s %s:  %s\n" );
-MKSTRING( TplWarn,    "Warning in template %s, line %d\n\t%s\n" );
-MKSTRING( FileLine,   "\tfrom %s line %d\n" );
-MKSTRING( ShDone,     "ShElL-OuTpUt-HaS-bEeN-cOmPlEtEd" );
-MKSTRING( NotStr,     "ERROR: %s is not a string\n" );
-MKSTRING( DevNull,    "/dev/null" );
-MKSTRING( ShellEnv,   "SHELL" );
-MKSTRING( Format,     "format" );
-MKSTRING( FileFormat, "%s%s\0%s.%s" );
-MKSTRING( Nil,        "" );
+MKSTRING( AllocErr,   "Allocation Failure");
+MKSTRING( AllocWhat,  "Could not allocate a %d byte %s\n");
+MKSTRING( Cannot,     "fserr %d: cannot %s %s:  %s\n");
+MKSTRING( DevNull,    "/dev/null");
+MKSTRING( Empty,      "");
+MKSTRING( FileFormat, "%s%s\0%s.%s");
+MKSTRING( FileLine,   "\tfrom %s line %d\n");
+MKSTRING( Format,     "format");
+MKSTRING( MemFile,    "in-mem file");
+MKSTRING( Nil,        "");
+MKSTRING( NotStr,     "ERROR: %s is not a string\n");
+MKSTRING( ShDone,     "ShElL-OuTpUt-HaS-bEeN-cOmPlEtEd");
+MKSTRING( ShellEnv,   "SHELL");
+MKSTRING( TplWarn,    "Warning in template %s, line %d\n\t%s\n");
 
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  *
  *  GLOBAL PROCEDURES
  */
 #ifndef HAVE_STRLCPY
-extern size_t strlcpy( char* dest, char const* src, size_t n );
+extern size_t strlcpy( char* dest, char const* src, size_t n);
 #endif
-#ifdef ENABLE_FMEMOPEN
+
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  *
  *  IF we have fopencookie or funopen, then we also have our own fmemopen
  */
-
-extern FILE * ag_fmemopen (void *buf, ssize_t len, char const *mode);
+#ifdef ENABLE_FMEMOPEN
+extern FILE * ag_fmemopen(void *buf, ssize_t len, char const *mode);
 #endif
+
 #include "proto.h"
 
 typedef union {
@@ -444,6 +490,9 @@ MODE v2c_t p2p VALUE( { NULL } );
 #else
 # define AG_ABEND(s)  ag_abend_at(s)
 #endif
+#define  AG_CANT(_op, _wh) \
+    AG_ABEND(aprf(zCannot, errno, _op, _wh, strerror(errno)))
+
 #ifdef DEBUG_FSM
 # define DEBUG
 #else
@@ -453,13 +502,8 @@ MODE v2c_t p2p VALUE( { NULL } );
 #define AG_ABEND_IN(t,m,s) \
     STMTS( pCurTemplate=(t); pCurMacro=(m); AG_ABEND(s);)
 
-extern void  ag_scmStrings_init(   void );
-extern void  ag_scmStrings_deinit( void );
-extern void  ag_scmStrings_free(   void );
-extern char* ag_scribble( size_t size );
-
 #if defined(DEBUG_ENABLED)
-  extern void manageAllocatedData( void* pd );
+  extern void manageAllocatedData(void* pd);
 #else
 # define manageAllocatedData(_ptr)
 #endif
@@ -498,13 +542,13 @@ extern char* ag_scribble( size_t size );
 #   define AG_SCM_STR02SCM(_s)          scm_makfrom0str(_s)
 #endif
 
-  static inline char* ag_scm2zchars( SCM s, tCC* type )
+  static inline char* ag_scm2zchars(SCM s, tCC* type)
   {
-    if (! AG_SCM_STRING_P( s ))
-        AG_ABEND( aprf( zNotStr, type ));
+    if (! AG_SCM_STRING_P(s))
+        AG_ABEND(aprf(zNotStr, type));
 
     if (SCM_SUBSTRP(s))
-        s = scm_makfromstr( SCM_CHARS(s), SCM_LENGTH(s), 0 );
+        s = scm_makfromstr(SCM_CHARS(s), SCM_LENGTH(s), 0);
     return SCM_CHARS(s);
   }
 
@@ -513,7 +557,7 @@ extern char* ag_scribble( size_t size );
 
 #else /* Guile 1.7 and following */
 
-  extern char* ag_scm2zchars( SCM s, tCC* type );
+  extern char* ag_scm2zchars(SCM s, tCC* type);
 
 # if GUILE_VERSION < 108000
 #   define AG_SCM_STRLEN(_s)            SCM_STRING_LENGTH(_s)
@@ -545,14 +589,14 @@ extern char* ag_scribble( size_t size );
 #define AG_SCM_LONG2SCM(_i)             gh_long2scm(_i)
 #define AG_SCM_SCM2LONG(_i)             gh_scm2long(_i)
 
-static inline SCM ag_eval( tCC* pzStr )
+static inline SCM ag_eval(tCC* pzStr)
 {
     SCM res;
     tCC* pzSaveScheme = pzLastScheme; /* Watch for nested calls */
     pzLastScheme = pzStr;
 
     res = ag_scm_c_eval_string_from_file_line(
-        pzStr, pCurTemplate->pzTplFile, pCurMacro->lineNo );
+        pzStr, pCurTemplate->pzTplFile, pCurMacro->lineNo);
 
     pzLastScheme = pzSaveScheme;
     return res;
