@@ -1,9 +1,7 @@
 /*
  *  defDirect.c
- *  $Id: defDirect.c,v 4.23 2009/01/01 16:51:42 bkorb Exp $
  *
- *  Time-stamp:        "2008-09-23 09:06:37 bkorb"
- *  Last Committed:    $Date: 2009/01/01 16:51:42 $
+ *  Time-stamp:        "2010-07-10 19:23:12 bkorb"
  *
  *  This module processes definition file directives.
  *
@@ -15,7 +13,7 @@
  *    trail='\+\+\+ End of Directives'
  *
  *  This file is part of AutoGen.
- *  AutoGen copyright (c) 1992-2009 by Bruce Korb - all rights reserved
+ *  AutoGen Copyright (c) 1992-2010 by Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -757,6 +755,7 @@ doDir_include( char* pzArg, char* pzScan )
         if (outTime <= stbf.st_mtime)
             outTime = stbf.st_mtime + 1;
     }
+
     if (inclSize == 0)
         return pzScan;
 
@@ -793,15 +792,16 @@ doDir_include( char* pzArg, char* pzScan )
         char*  pz = pzScan;
 
         if (fp == NULL)
-            AG_ABEND( aprf( zCannot, errno, "open file", zFullName,
-                            strerror( errno )));
+            AG_CANT("open file", zFullName);
+
+        if (pfDepends != NULL)
+            append_source_name(zFullName);
 
         do  {
             size_t rdct = fread((void*)pz, (size_t)1, inclSize, fp);
 
             if (rdct == 0)
-                AG_ABEND( aprf( zCannot, errno, "read file", zFullName,
-                                strerror( errno )));
+                AG_CANT("read file", zFullName);
 
             pz += rdct;
             inclSize -= rdct;
@@ -936,7 +936,7 @@ doDir_shell( char* pzArg, char* pzScan )
      *  The output time will always be the current time.
      *  The dynamic content is always current :)
      */
-    outTime = time( NULL );
+    outTime = time(NULL);
 
     /*
      *  IF there are no data after the '#shell' directive,
@@ -947,10 +947,11 @@ doDir_shell( char* pzArg, char* pzScan )
         return pzScan;
 
     {
+        static char const noend[] =
+            "Missing #endshell after '#shell' in %s on line %d\n";
         char* pz = strstr( pzScan, zEndShell );
         if (pz == NULL)
-            AG_ABEND( aprf("Missing #endshell after '#shell' in %s on line %d\n",
-                           pCurCtx->pzCtxFname, pCurCtx->lineNo ));
+            AG_ABEND(aprf(noend, pCurCtx->pzCtxFname, pCurCtx->lineNo));
 
         while (pzScan < pz) {
             if (*(pzScan++) == '\n') pCurCtx->lineNo++;
@@ -978,10 +979,14 @@ doDir_shell( char* pzArg, char* pzScan )
      *  "file text" that is used for more definitions.
      */
     pzText = runShell( pzText );
-    if (  (pzText == NULL)
-       || (*pzText == NUL))
+    if (pzText == NULL)
         return pzScan;
 
+    if (*pzText == NUL) {
+        AGFREE(pzText);
+        return pzScan;
+    }
+
     /*
      *  Get the space for the output data and for context overhead.
      *  This is an extra allocation and copy, but easier than rewriting
