@@ -1,7 +1,6 @@
 /*
- *  $Id: 957a5dc60706d14426d5b9858a9a9e661a8ff84c $
  *
- *  Time-stamp:        "2010-02-24 08:43:01 bkorb"
+ *  Time-stamp:        "2010-07-24 09:06:11 bkorb"
  *
  *  Create a perfect hash function program and use it to compute
  *  index values for a list of provided names.  It also documents how
@@ -26,13 +25,13 @@
 
 #ifndef SHELL_ENABLED
 SCM
-ag_scm_make_gperf( SCM name, SCM hlist )
+ag_scm_make_gperf(SCM name, SCM hlist)
 {
     return SCM_UNDEFINED;
 }
 
 SCM
-ag_scm_gperf( SCM name, SCM str )
+ag_scm_gperf(SCM name, SCM str)
 {
     return SCM_UNDEFINED;
 }
@@ -65,45 +64,45 @@ ag_scm_gperf( SCM name, SCM str )
  *       temporary directory used to stash all the files.
 =*/
 SCM
-ag_scm_make_gperf( SCM name, SCM hlist )
+ag_scm_make_gperf(SCM name, SCM hlist)
 {
-    SCM     newline  = AG_SCM_STR2SCM("\n", (size_t)1);
-    char*   pzName   = ag_scm2zchars( name, "gperf name" );
-    char*   pzList;
+    static ag_bool do_cleanup = AG_TRUE;
 
-    if (! AG_SCM_STRING_P( name ))
+    char const * pzName  = ag_scm2zchars(name, "gperf name");
+    char const * pzList;
+    SCM          newline = AG_SCM_STR2SCM("\n", (size_t)1);
+
+    if (! AG_SCM_STRING_P(name))
         return SCM_UNDEFINED;
 
     /*
      *  Construct the newline separated list of values
      */
-    hlist  = ag_scm_join( newline, hlist );
-    pzList = ag_scm2zchars( hlist, "hash list" );
+    hlist  = ag_scm_join(newline, hlist);
+    pzList = ag_scm2zchars(hlist, "hash list");
 
     /*
      *  Stash the concatenated list somewhere, hopefully without an alloc.
      */
     {
-        static int  const  makeGperfLine = __LINE__ + 2;
-        static char const* pzCleanup =
-            "(add-cleanup \"rm -rf ${gpdir}\")";
-        char* pzCmd = aprf( zMakeGperf, pzList, pzName );
+        char* pzCmd = aprf(zMakeGperf, pzList, pzName);
 
         /*
          *  Run the command and ignore the results.
          *  In theory, the program should be ready.
          */
-        pzList = runShell( pzCmd );
-        AGFREE( pzCmd );
-        if (pzList != NULL)
-            free( pzList );
+        pzList = runShell(pzCmd);
+        AGFREE(pzCmd);
 
-        if (pzCleanup != NULL) {
-            (void)ag_scm_c_eval_string_from_file_line(
-                pzCleanup, __FILE__, makeGperfLine );
-            pzCleanup = NULL;
-        }
+        if (pzList != NULL)
+            free((void *)pzList);
     }
+
+    if (do_cleanup) {
+        SCM_EVAL_CONST("(add-cleanup \"rm -rf ${gpdir}\")");
+        do_cleanup = AG_FALSE;
+    }
+
     return SCM_BOOL_T;
 }
 
@@ -126,26 +125,26 @@ ag_scm_make_gperf( SCM name, SCM hlist )
  *       See the documentation for @command{gperf(1GNU)} for more details.
 =*/
 SCM
-ag_scm_gperf( SCM name, SCM str )
+ag_scm_gperf(SCM name, SCM str)
 {
-    char*   pzCmd;
-    char*   pzStr  = ag_scm2zchars( str,  "key-to-hash" );
-    char*   pzName = ag_scm2zchars( name, "gperf name" );
+    char const * pzCmd;
+    char const * pzStr  = ag_scm2zchars(str,  "key-to-hash");
+    char const * pzName = ag_scm2zchars(name, "gperf name");
 
     /*
      *  Format the gperf command and check the result.  If it fits in
      *  scribble space, use that.
      *  (If it does fit, then the test string fits already).
      */
-    pzCmd = aprf( zRunGperf, pzName, pzStr );
-    pzStr = runShell( pzCmd );
+    pzCmd = aprf(zRunGperf, pzName, pzStr);
+    pzStr = runShell(pzCmd);
     if (*pzStr == NUL)
         str = SCM_UNDEFINED;
     else
-        str = AG_SCM_STR02SCM( pzStr );
+        str = AG_SCM_STR02SCM(pzStr);
 
-    AGFREE( pzCmd );
-    AGFREE( pzStr );
+    AGFREE((void *)pzCmd);
+    AGFREE((void *)pzStr);
     return str;
 }
 #endif
