@@ -1,8 +1,8 @@
 
-/*
- *  $Id: 1c97dc5ed8495653af850423a4c24b7105aac1df $
+/**
+ * \file expOutput.c
  *
- *  Time-stamp:        "2010-02-24 08:42:59 bkorb"
+ *  Time-stamp:        "2010-07-21 17:35:01 bkorb"
  *
  *  This module implements the output file manipulation function
  *
@@ -40,13 +40,8 @@ static int            suspAllocCt = 0;
 static tSuspendName*  pSuspended  = NULL;
 static int            outputDepth = 1;
 
-/* = = = START-STATIC-FORWARD = = = */
-static void
-addWriteAccess( char* pzFileName );
-/* = = = END-STATIC-FORWARD = = = */
-
 LOCAL void
-removeWriteAccess( int fd )
+make_readonly(int fd)
 {
     struct stat    sbuf;
 
@@ -54,9 +49,9 @@ removeWriteAccess( int fd )
      *  If the output is supposed to be writable, then also see if
      *  it is a temporary condition (set vs. a command line option).
      */
-    if (ENABLED_OPT( WRITABLE )) {
-        if (! HAVE_OPT( WRITABLE ))
-            CLEAR_OPT( WRITABLE );
+    if (ENABLED_OPT(WRITABLE)) {
+        if (! HAVE_OPT(WRITABLE))
+            CLEAR_OPT(WRITABLE);
         return;
     }
 
@@ -65,18 +60,18 @@ removeWriteAccess( int fd )
      *  bits that do not provide for write access
      */
 #   define USE_MASK ((unsigned)(~(S_IWUSR|S_IWGRP|S_IWOTH)))
-    fstat( fd, &sbuf );
+    fstat(fd, &sbuf);
 
     /*
      *  Mask off the write permission bits, but ensure that
      *  the user read bit is set.
      */
     sbuf.st_mode = ((unsigned)sbuf.st_mode & USE_MASK) | S_IRUSR;
-    fchmod( fd, sbuf.st_mode & S_IAMB );
+    fchmod(fd, sbuf.st_mode & S_IAMB);
 }
 
 static void
-addWriteAccess( char* pzFileName )
+make_writable(char* pzFileName)
 {
     struct stat sbuf;
 
@@ -84,16 +79,16 @@ addWriteAccess( char* pzFileName )
     /*
      *  "stat(2)" does not initialize the entire structure.
      */
-    memset( &sbuf, NUL, sizeof(sbuf) );
+    memset(&sbuf, NUL, sizeof(sbuf));
 #endif
 
-    stat( pzFileName, &sbuf );
+    stat(pzFileName, &sbuf);
 
     /*
      *  Or in the user write bit
      */
     sbuf.st_mode |= S_IWUSR;
-    chmod( pzFileName, sbuf.st_mode & S_IAMB );
+    chmod(pzFileName, sbuf.st_mode & S_IAMB);
 }
 
 
@@ -107,7 +102,7 @@ addWriteAccess( char* pzFileName )
  *  @xref{output controls}.
 =*/
 SCM
-ag_scm_out_delete( void )
+ag_scm_out_delete(void)
 {
     tSCC zSkipMsg[] = "NOTE:  skipping file '%s'\n";
 
@@ -115,9 +110,9 @@ ag_scm_out_delete( void )
      *  Delete the current output file
      */
     if (OPT_VALUE_TRACE > TRACE_DEBUG_MESSAGE)
-        fprintf( pfTrace, zSkipMsg, pCurFp->pzOutName );
+        fprintf(pfTrace, zSkipMsg, pCurFp->pzOutName);
     outputDepth = 1;
-    longjmp( fileAbort, PROBLEM );
+    longjmp(fileAbort, PROBLEM);
     /* NOTREACHED */
     return SCM_UNDEFINED;
 }
@@ -128,25 +123,34 @@ ag_scm_out_delete( void )
  * what:   change name of output file
  * exparg: new-name, new name for the current output file
  *
- * doc:    Rename current output file.  @xref{output controls}.
- *         Please note: changing the name will not save a temporary
- *         file from being deleted.  It @i{may}, however, be used on the
- *         root output file.
+ * doc:
+ *
+ *  Rename current output file.  @xref{output controls}.
+ *  Please note: changing the name will not save a temporary file from
+ *  being deleted.  It @i{may}, however, be used on the root output file.
+ *
+ *  NOTE: if you are creating a dependency file, @i{both} the original
+ *  file name @i{and} the new file name will be listed as derived files.
 =*/
 SCM
-ag_scm_out_move( SCM new_file )
+ag_scm_out_move(SCM new_file)
 {
-    size_t sz = AG_SCM_STRLEN( new_file );
-    char*  pz = (char*)AGALOC( sz + 1, "new file name string" );
-    memcpy( pz, AG_SCM_CHARS( new_file ), sz );
+    size_t sz = AG_SCM_STRLEN(new_file);
+    char*  pz = (char*)AGALOC(sz + 1, "new file name string");
+    memcpy(pz, AG_SCM_CHARS(new_file), sz);
     pz[ sz ] = NUL;
 
     if (OPT_VALUE_TRACE > TRACE_DEBUG_MESSAGE)
-        fprintf( pfTrace, "renaming %s to %s\n",  pCurFp->pzOutName, pz);
+        fprintf(pfTrace, "renaming %s to %s\n",  pCurFp->pzOutName, pz);
     rename(pCurFp->pzOutName, pz);
+
+    if (pfDepends != NULL)
+        fprintf(pfDepends, " \\\n\t%s", pz);
+
     if ((pCurFp->flags & FPF_STATIC_NM) == 0)
-        AGFREE( (void*)pCurFp->pzOutName );
-    AGDUPSTR( pCurFp->pzOutName, pz, "file name" );
+        AGFREE((void*)pCurFp->pzOutName);
+
+    AGDUPSTR(pCurFp->pzOutName, pz, "file name");
     pCurFp->flags &= ~FPF_STATIC_NM;
     return SCM_UNDEFINED;
 }
@@ -166,23 +170,26 @@ ag_scm_out_move( SCM new_file )
  *  are returned by the function.
 =*/
 SCM
-ag_scm_out_pop( SCM ret_contents )
+ag_scm_out_pop(SCM ret_contents)
 {
     SCM res = SCM_UNDEFINED;
 
     if (pCurFp->pPrev == NULL)
-        AG_ABEND( "ERROR:  Cannot pop output with no output pushed\n" );
+        AG_ABEND("ERROR:  Cannot pop output with no output pushed\n");
 
-    if (AG_SCM_BOOL_P( ret_contents ) && SCM_NFALSEP( ret_contents )) {
-        unsigned long pos = ftell( pCurFp->pFile );
+    if (AG_SCM_BOOL_P(ret_contents) && SCM_NFALSEP(ret_contents)) {
+        unsigned long pos = ftell(pCurFp->pFile);
 
-        if (pos != 0) {
-            char* pz = ag_scribble( (size_t)pos );
-            rewind( pCurFp->pFile );
-            if (fread( pz, (size_t)pos, (size_t)1, pCurFp->pFile ) != 1)
-                AG_ABEND( aprf( "Error %d (%s) rereading output\n",
-                                errno, strerror( errno )));
-            res = AG_SCM_STR2SCM( pz, pos );
+        if (pos == 0)
+            res = AG_SCM_STR2SCM("", pos);
+
+        else {
+            char* pz = ag_scribble((size_t)pos);
+            rewind(pCurFp->pFile);
+            if (fread(pz, (size_t)pos, (size_t)1, pCurFp->pFile) != 1)
+                AG_ABEND(aprf("Error %d (%s) rereading output\n",
+                              errno, strerror(errno)));
+            res = AG_SCM_STR2SCM(pz, pos);
         }
     }
 
@@ -190,7 +197,7 @@ ag_scm_out_pop( SCM ret_contents )
         fputs("out-pop\n", pfTrace);
 
     outputDepth--;
-    closeOutput( AG_FALSE );
+    closeOutput(AG_FALSE);
     return res;
 }
 
@@ -208,25 +215,25 @@ ag_scm_out_pop( SCM ret_contents )
  *  tag names are forgotten as soon as the file has been "resumed".
 =*/
 SCM
-ag_scm_out_suspend( SCM suspName )
+ag_scm_out_suspend(SCM suspName)
 {
     if (pCurFp->pPrev == NULL)
-        AG_ABEND( "ERROR:  Cannot pop output with no output pushed" );
+        AG_ABEND("ERROR:  Cannot pop output with no output pushed");
 
     if (++suspendCt > suspAllocCt) {
         suspAllocCt += 8;
         if (pSuspended == NULL)
             pSuspended = (tSuspendName*)
-                AGALOC( suspAllocCt * sizeof( tSuspendName ),
-                        "suspended file list" );
+                AGALOC(suspAllocCt * sizeof(tSuspendName),
+                        "suspended file list");
         else
             pSuspended = (tSuspendName*)
-                AGREALOC( (void*)pSuspended,
-                          suspAllocCt * sizeof( tSuspendName ),
-                          "augmenting suspended file list" );
+                AGREALOC((void*)pSuspended,
+                         suspAllocCt * sizeof(tSuspendName),
+                         "augmenting suspended file list");
     }
 
-    pSuspended[ suspendCt-1 ].pzSuspendName = gh_scm2newstr( suspName, NULL );
+    pSuspended[ suspendCt-1 ].pzSuspendName = gh_scm2newstr(suspName, NULL);
     pSuspended[ suspendCt-1 ].pOutDesc      = pCurFp;
     if (OPT_VALUE_TRACE >= TRACE_EXPRESSIONS)
         fprintf(pfTrace, "suspended output to '%s'\n",
@@ -249,16 +256,16 @@ ag_scm_out_suspend( SCM suspName )
  *  name given to this routine as its argument.
 =*/
 SCM
-ag_scm_out_resume( SCM suspName )
+ag_scm_out_resume(SCM suspName)
 {
     int  ix  = 0;
-    tCC* pzName = ag_scm2zchars( suspName, "resume name" );
+    char const * pzName = ag_scm2zchars(suspName, "resume name");
 
     for (; ix < suspendCt; ix++) {
-        if (strcmp( pSuspended[ ix ].pzSuspendName, pzName ) == 0) {
+        if (strcmp(pSuspended[ ix ].pzSuspendName, pzName) == 0) {
             pSuspended[ ix ].pOutDesc->pPrev = pCurFp;
             pCurFp = pSuspended[ ix ].pOutDesc;
-            free( (void*)pSuspended[ ix ].pzSuspendName ); /* Guile alloc */
+            free((void*)pSuspended[ ix ].pzSuspendName); /* Guile alloc */
             if (ix < --suspendCt)
                 pSuspended[ ix ] = pSuspended[ suspendCt ];
             ++outputDepth;
@@ -268,8 +275,8 @@ ag_scm_out_resume( SCM suspName )
         }
     }
 
-    AG_ABEND( aprf( "ERROR: no output file was suspended as ``%s''\n",
-                    pzName ));
+    AG_ABEND(aprf("ERROR: no output file was suspended as ``%s''\n",
+                  pzName));
     /* NOTREACHED */
     return SCM_UNDEFINED;
 }
@@ -284,7 +291,7 @@ ag_scm_out_resume( SCM suspName )
  *  @code{(begin (out-resume <name>) (out-pop #t))}
 =*/
 SCM
-ag_scm_out_emit_suspended( SCM suspName )
+ag_scm_out_emit_suspended(SCM suspName)
 {
     (void)ag_scm_out_resume(suspName);
     return ag_scm_out_pop(SCM_BOOL_T);
@@ -310,12 +317,12 @@ ag_scm_out_emit_suspended( SCM suspName )
  *       suspended output stream.
 =*/
 SCM
-ag_scm_ag_fprintf( SCM port, SCM fmt, SCM alist )
+ag_scm_ag_fprintf(SCM port, SCM fmt, SCM alist)
 {
     static char const invalid_z[] = "ag-fprintf: 'port' is invalid";
-    int   list_len = scm_ilength( alist );
-    char* pzFmt    = ag_scm2zchars( fmt, zFormat );
-    SCM   res      = run_printf( pzFmt, list_len, alist );
+    int   list_len = scm_ilength(alist);
+    char const * pzFmt = ag_scm2zchars(fmt, zFormat);
+    SCM   res      = run_printf(pzFmt, list_len, alist);
 
     /*
      *  If "port" is a string, it must match one of the suspended outputs.
@@ -323,10 +330,10 @@ ag_scm_ag_fprintf( SCM port, SCM fmt, SCM alist )
      */
     if (AG_SCM_STRING_P(port)) {
         int  ix  = 0;
-        tCC* pzName = ag_scm2zchars( port, "resume name" );
+        char const * pzName = ag_scm2zchars(port, "resume name");
 
         for (; ix < suspendCt; ix++) {
-            if (strcmp( pSuspended[ ix ].pzSuspendName, pzName ) == 0) {
+            if (strcmp(pSuspended[ ix ].pzSuspendName, pzName) == 0) {
                 tFpStack* pSaveFp = pCurFp;
                 pCurFp = pSuspended[ ix ].pOutDesc;
                 (void) ag_scm_emit(res);
@@ -337,9 +344,10 @@ ag_scm_ag_fprintf( SCM port, SCM fmt, SCM alist )
     }
 
     /*
-     *  If "port" is a number, it is an index into the output stack with
-     *  "0" (zero) representing the current output and "1" the last suspended
-     *  output.  If the number is out of range, we'll fall through to the abend.
+     *  If "port" is a number, it is an index into the output stack with "0"
+     *  (zero) representing the current output and "1" the last suspended
+     *  output.  If the number is out of range, we'll fall through to the
+     *  abend.
      */
     else if (AG_SCM_NUM_P(port)) {
         tFpStack* pSaveFp = pCurFp;
@@ -379,7 +387,7 @@ open_output_file(char const * fname, size_t nmsz, char const * mode, int flags)
     tFpStack* p  = AGALOC(sizeof(*p), "out file stack");
 
     pz = (char*)AGALOC(nmsz + 1, "file name string");
-    memcpy( pz, fname, nmsz );
+    memcpy(pz, fname, nmsz);
     pz[ nmsz ] = NUL;
     memset(p, NUL, sizeof(*p));
     p->pzOutName = pz;
@@ -390,22 +398,25 @@ open_output_file(char const * fname, size_t nmsz, char const * mode, int flags)
      */
     if ((*mode == 'w') && ((flags & FPF_NOUNLINK) == 0)) {
         if ((unlink(pz) != 0) && (errno != ENOENT))
-            AG_ABEND(aprf(zCannot, errno, "unlink", pz, strerror(errno)));
+            AG_CANT("unlink", pz);
     }
 
     p->pFile = fopen(pz, mode);
     if (p->pFile == NULL)
-        AG_ABEND(aprf( zCannot, errno, "open for output", pz, strerror(errno)));
+        AG_CANT("open for output", pz);
 
     p->pPrev = pCurFp;
     pCurFp   = p;
     p->flags = FPF_FREE | flags;
     outputDepth++;
 
-    addWriteAccess(pz);
+    make_writable(pz);
 
     if (OPT_VALUE_TRACE > TRACE_DEBUG_MESSAGE)
         fprintf(pfTrace, "open_output_file '%s' mode %s\n", fname, mode);
+
+    if ((pfDepends != NULL) && ((flags & FPF_TEMPFILE) == 0))
+        fprintf(pfDepends, " \\\n\t%s", fname);
 }
 
 /*=gfunc out_push_add
@@ -418,15 +429,15 @@ open_output_file(char const * fname, size_t nmsz, char const * mode, int flags)
  *  purged, but appended to.  @xref{output controls}.
 =*/
 SCM
-ag_scm_out_push_add( SCM new_file )
+ag_scm_out_push_add(SCM new_file)
 {
     static char const append_mode[] = "a" FOPEN_BINARY_FLAG "+";
 
-    if (! AG_SCM_STRING_P( new_file ))
+    if (! AG_SCM_STRING_P(new_file))
         AG_ABEND("No output file specified to add to");
 
-    open_output_file( AG_SCM_CHARS(new_file), AG_SCM_STRLEN(new_file),
-                      append_mode, 0);
+    open_output_file(AG_SCM_CHARS(new_file), AG_SCM_STRLEN(new_file),
+                     append_mode, 0);
 
     return SCM_UNDEFINED;
 }
@@ -446,47 +457,53 @@ ag_scm_out_push_add( SCM new_file )
  *  @xref{output controls}.
 =*/
 SCM
-ag_scm_out_push_new( SCM new_file )
+ag_scm_out_push_new(SCM new_file)
 {
     static char const write_mode[] = "w" FOPEN_BINARY_FLAG "+";
 
-    if (AG_SCM_STRING_P( new_file )) {
-        open_output_file( AG_SCM_CHARS(new_file), AG_SCM_STRLEN( new_file ),
-                          write_mode, 0);
-        return SCM_UNDEFINED;
+    if (AG_SCM_STRING_P(new_file)) {
+        open_output_file(AG_SCM_CHARS(new_file), AG_SCM_STRLEN(new_file),
+                         write_mode, 0);
     }
 
 #if defined(ENABLE_FMEMOPEN)
-    if (! HAVE_OPT( NO_FMEMOPEN ))
+    else if (HAVE_OPT(NO_FMEMOPEN))
 #endif
     {
+        static char const mk_tmp_dir[] = "(make-tmp-dir)";
+        static int  const line_no      = __LINE__ - 1;
+
         /*
          *  IF we do not have fopencookie(3GNU) or funopen(3BSD), then this
          *  block is a pure "else" clause.  If we do have one of those, then
          *  the block is executed when a file name is not specified *and*
          *  --no-fmemopen was *not* selected.
          */
-        static char * pzTemp = NULL;
+        static char * temp_pat = NULL;
         static size_t tmplen = 0;
-
+        char *  tmp_fnm;
         int     tmpfd;
 
-        if (pzTemp == NULL) {
-            pzTemp = mkstempPat();
-            tmplen = strlen(pzTemp) + 1;
+        if (temp_pat == NULL) {
+            ag_scm_c_eval_string_from_file_line(mk_tmp_dir, __FILE__, line_no);
+            temp_pat = runShell("echo ${tmp_dir}/ag-XXXXXX");
+            tmplen   = strlen(temp_pat);
         }
 
-        memcpy(pzTemp + tmplen, pzTemp, tmplen);
-        tmpfd = mkstemp(pzTemp + tmplen);
-        if (tmpfd < 0)
-            AG_ABEND( aprf( "failed to create temp file from `%s'", pzTemp ));
+        tmp_fnm = ag_scribble(tmplen + 1);
+        memcpy(tmp_fnm, temp_pat, tmplen + 1);
+        tmpfd = mkstemp(tmp_fnm);
 
-        open_output_file(pzTemp + tmplen, tmplen - 1, write_mode, 0);
+        if (tmpfd < 0)
+            AG_ABEND(aprf("failed to create temp file from `%s'", temp_pat));
+
+        open_output_file(tmp_fnm, tmplen, write_mode, FPF_TEMPFILE);
         close(tmpfd);
-        return SCM_UNDEFINED;
     }
 #if defined(ENABLE_FMEMOPEN)
 
+    else
+
     {
         char *     pzNewFile;
         tFpStack * p;
@@ -495,16 +512,15 @@ ag_scm_out_push_new( SCM new_file )
          *  This block is used IFF ENABLE_FMEMOPEN is defined and if
          *  --no-fmemopen is selected on the command line.
          */
-        p = (tFpStack*)AGALOC( sizeof( tFpStack ), "new - out file stack" );
+        p = (tFpStack*)AGALOC(sizeof(tFpStack), "out file stack");
         p->pPrev  = pCurFp;
         p->flags  = FPF_FREE;
         p->pFile  = ag_fmemopen(NULL, (size_t)0, "wb+");
-        pzNewFile = (char*)"in-mem buffer";
+        pzNewFile = (char*)zMemFile;
         p->flags |= FPF_STATIC_NM | FPF_NOUNLINK | FPF_NOCHMOD;
 
         if (p->pFile == NULL)
-            AG_ABEND( aprf( zCannot, errno, "open for write", pzNewFile,
-                            strerror( errno )));
+            AG_CANT("open 'wb+'", pzNewFile);
 
         p->pzOutName = pzNewFile;
         outputDepth++;
@@ -512,9 +528,10 @@ ag_scm_out_push_new( SCM new_file )
 
         if (OPT_VALUE_TRACE > TRACE_DEBUG_MESSAGE)
             fprintf(pfTrace, "out-push-new on temp file\n");
-        return SCM_UNDEFINED;
     }
 #endif /* ENABLE_FMEMOPEN */
+
+    return SCM_UNDEFINED;
 }
 
 
@@ -531,47 +548,46 @@ ag_scm_out_push_new( SCM new_file )
  *  @code{switch} it.  @xref{output controls}.
 =*/
 SCM
-ag_scm_out_switch( SCM new_file )
+ag_scm_out_switch(SCM new_file)
 {
     struct utimbuf tbuf;
     char*  pzNewFile;
 
-    if (! AG_SCM_STRING_P( new_file ))
+    if (! AG_SCM_STRING_P(new_file))
         return SCM_UNDEFINED;
     {
-        size_t sz = AG_SCM_STRLEN( new_file );
-        pzNewFile = (char*)AGALOC( sz + 1, "new file name string" );
-        memcpy( pzNewFile, AG_SCM_CHARS( new_file ), sz );
+        size_t sz = AG_SCM_STRLEN(new_file);
+        pzNewFile = AGALOC(sz + 1, "new file name");
+        memcpy(pzNewFile, AG_SCM_CHARS(new_file), sz);
         pzNewFile[ sz ] = NUL;
     }
 
     /*
      *  IF no change, THEN ignore this
      */
-    if (strcmp( pCurFp->pzOutName, pzNewFile ) == 0) {
-        AGFREE( (void*)pzNewFile );
+    if (strcmp(pCurFp->pzOutName, pzNewFile) == 0) {
+        AGFREE((void*)pzNewFile);
         return SCM_UNDEFINED;
     }
 
-    removeWriteAccess( fileno( pCurFp->pFile ));
+    make_readonly(fileno(pCurFp->pFile));
 
     /*
      *  Make sure we get a new file pointer!!
      *  and try to ensure nothing is in the way.
      */
-    unlink( pzNewFile );
-    if (   freopen( pzNewFile, "w" FOPEN_BINARY_FLAG "+", pCurFp->pFile )
-        != pCurFp->pFile)
+    unlink(pzNewFile);
+    if (  freopen(pzNewFile, "w" FOPEN_BINARY_FLAG "+", pCurFp->pFile)
+       != pCurFp->pFile)
 
-        AG_ABEND( aprf( zCannot, errno, "freopen", pzNewFile,
-                        strerror( errno )));
+        AG_CANT("freopen", pzNewFile);
 
     /*
      *  Set the mod time on the old file.
      */
-    tbuf.actime  = time( NULL );
+    tbuf.actime  = time(NULL);
     tbuf.modtime = outTime;
-    utime( pCurFp->pzOutName, &tbuf );
+    utime(pCurFp->pzOutName, &tbuf);
     if (OPT_VALUE_TRACE > TRACE_DEBUG_MESSAGE)
         fprintf(pfTrace, "switching output from %s to '%s'\n",
                 pCurFp->pzOutName, pzNewFile);
@@ -588,9 +604,9 @@ ag_scm_out_switch( SCM new_file )
  *       @xref{output controls}.
 =*/
 SCM
-ag_scm_out_depth( void )
+ag_scm_out_depth(void)
 {
-    return AG_SCM_INT2SCM( outputDepth );
+    return AG_SCM_INT2SCM(outputDepth);
 }
 
 
@@ -603,11 +619,11 @@ ag_scm_out_depth( void )
  *       @xref{output controls}.
 =*/
 SCM
-ag_scm_out_name( void )
+ag_scm_out_name(void)
 {
     tFpStack* p = pCurFp;
     while (p->flags & FPF_UNLINK)  p = p->pPrev;
-    return AG_SCM_STR02SCM( (void*)p->pzOutName );
+    return AG_SCM_STR02SCM((void*)p->pzOutName);
 }
 
 
@@ -618,30 +634,30 @@ ag_scm_out_name( void )
  *       It rewinds and reads the file to count newlines.
 =*/
 SCM
-ag_scm_out_line( void )
+ag_scm_out_line(void)
 {
     int lineNum = 1;
 
     do {
-        long svpos = ftell( pCurFp->pFile );
+        long svpos = ftell(pCurFp->pFile);
         long pos   = svpos;
 
         if (pos == 0)
             break;
 
-        rewind( pCurFp->pFile );
+        rewind(pCurFp->pFile);
         do {
-            int ich = fgetc( pCurFp->pFile );
+            int ich = fgetc(pCurFp->pFile);
             unsigned char ch = ich;
             if (ich < 0)
                 break;
             if (ch == (unsigned char)'\n')
                 lineNum++;
         } while (--pos > 0);
-        fseek( pCurFp->pFile, svpos, SEEK_SET );
+        fseek(pCurFp->pFile, svpos, SEEK_SET);
     } while(0);
 
-    return AG_SCM_INT2SCM( lineNum );
+    return AG_SCM_INT2SCM(lineNum);
 }
 
 #if 0 /* for compilers that do not like C++ comments... */
@@ -798,7 +814,7 @@ ag_scm_make_header_guard(SCM name)
         if (strsz > sizeof(z))
             p = AGALOC(strsz, "ifndef guard");
         snprintf(p, strsz, ifndef, gpz);
-        name = AG_SCM_STR02SCM( p );
+        name = AG_SCM_STR02SCM(p);
         if (p != z)
             AGFREE(p);
     }
