@@ -1,7 +1,7 @@
 /* -*- buffer-read-only: t -*- vi: set ro:
  *
  * Prototypes for agen5
- * Generated Fri Jun 25 14:11:21 PDT 2010
+ * Generated Sun Jul 25 09:16:24 PDT 2010
  */
 #ifndef AGEN5_PROTO_H_GUARD
 #define AGEN5_PROTO_H_GUARD 1
@@ -22,7 +22,10 @@ loadCgi( void );
  *  Extracted from agInit.c
  */
 LOCAL void
-initialize( int arg_ct, char** arg_vec );
+initialize(int arg_ct, char** arg_vec);
+
+LOCAL void
+config_dep(tOptions* pOptions, tOptDesc* pOptDesc);
 
 /*
  *  Extracted from agShell.c
@@ -48,36 +51,33 @@ runShell( char const*  pzCmd );
  *  Extracted from agUtils.c
  */
 LOCAL char *
-aprf( char const* pzFmt, ... );
-
-LOCAL char *
-mkstempPat( void );
+aprf(char const * pzFmt, ...);
 
 LOCAL void
-doOptions( int arg_ct, char** arg_vec );
+doOptions(int arg_ct, char ** arg_vec);
 
-LOCAL tCC*
-getDefine( tCC* pzDefName, ag_bool check_env );
+LOCAL char const *
+getDefine(char const * pzDefName, ag_bool check_env);
 
 LOCAL char*
-spanQuote( char* pzQte );
+spanQuote(char* pzQte);
 
-LOCAL tCC*
-skipScheme( tCC* pzSrc,  tCC* pzEnd );
+LOCAL char const *
+skipScheme(char const * pzSrc,  char const * pzEnd);
 
 LOCAL int
 count_nl(char const * pz);
 
-LOCAL tCC*
-skipExpression( tCC* pzSrc, size_t len );
+LOCAL char const *
+skipExpression(char const * pzSrc, size_t len);
 
 /*
  *  Extracted from autogen.c
  */
 LOCAL void
-ag_abend_at( tCC* pzMsg
+ag_abend_at(char const * pzMsg
 #ifdef DEBUG_ENABLED
-    , tCC* pzFile, int line
+            , char const * pzFile, int line
 #endif
     );
 
@@ -103,61 +103,58 @@ processDirective( char* pzScan );
  *  Extracted from defFind.c
  */
 LOCAL int
-canonicalizeName( char* pzD, char const* pzS, int srcLen );
+canonicalizeName(char* pzD, char const* pzS, int srcLen);
 
 LOCAL tDefEntry*
-findDefEntry( char* pzName, ag_bool* pIsIndexed );
+findDefEntry(char * pzName, ag_bool* pIsIndexed);
 
 LOCAL void
 print_used_defines(void);
 
 LOCAL tDefEntry**
-findEntryList( char* pzName );
+findEntryList(char* pzName);
 
 /*
  *  Extracted from defLex.c
  */
 LOCAL te_dp_event
-yylex( void );
+yylex(void);
 
 LOCAL void
-yyerror( char* s );
+yyerror(char* s);
 
 /*
  *  Extracted from defLoad.c
  */
-LOCAL void
-freeEntry( tDefEntry* pDE );
-
 LOCAL tDefEntry*
-getEntry( void );
+getEntry(void);
 
 LOCAL void
 print_def(tDefEntry * pDef);
 
 LOCAL tDefEntry*
-findPlace( char* name, tCC* pzIndex );
+findPlace(char* name, tCC* pzIndex);
 
 LOCAL void
-readDefines( void );
+readDefines(void);
 
 LOCAL void
-unloadDefs( void );
+unloadDefs(void);
 
 /*
  *  Extracted from expGuile.c
  */
 LOCAL teGuileType
-gh_type_e( SCM typ );
+gh_type_e(SCM typ);
 
 LOCAL SCM
-ag_scm_c_eval_string_from_file_line( tCC* pzExpr, tCC* pzFile, int line );
+ag_scm_c_eval_string_from_file_line(tCC* pzExpr, tCC* pzFile, int line);
 
 /*
  *  Extracted from expOutput.c
  */
 LOCAL void
-removeWriteAccess( int fd );
+make_readonly(int fd);
 
 LOCAL void
 open_output_file(char const * fname, size_t nmsz, char const * mode, int flags);
@@ -166,7 +163,7 @@ open_output_file(char const * fname, size_t nmsz, char const * mode, int flags);
  *  Extracted from expPrint.c
  */
 LOCAL SCM
-run_printf( char* pzFmt, int len, SCM alist );
+run_printf(char const * pzFmt, int len, SCM alist);
 
 /*
  *  Extracted from funcDef.c
@@ -178,63 +175,82 @@ parseMacroArgs(tTemplate* pT, tMacro* pMac);
  *  Extracted from funcEval.c
  */
 LOCAL tCC*
-resolveSCM( SCM s );
+resolveSCM(SCM s);
 
 LOCAL tCC*
-evalExpression( ag_bool* pMustFree );
+evalExpression(ag_bool* pMustFree);
 
 LOCAL SCM
-eval( char const* pzExpr );
+eval(char const* pzExpr);
 
 /*
  *  Extracted from loadPseudo.c
  */
-LOCAL tCC*
-doSuffixSpec(tCC * const pzData, tCC* pzFileName, int lineNo);
+LOCAL char const *
+doSuffixSpec(char const * const pzData, char const * pzFileName, int lineNo);
 
-LOCAL tCC*
-loadPseudoMacro( tCC* pzData, tCC* pzFileName );
+LOCAL char const *
+loadPseudoMacro(char const * pzData, char const * pzFileName);
+
+/*
+ *  Extracted from scmStrings.c
+ */
+LOCAL void
+ag_scribble_init(void);
+
+LOCAL void
+ag_scribble_deinit(void);
+
+LOCAL void
+ag_scribble_free(void);
+
+LOCAL char*
+ag_scribble(size_t size);
 
 /*
  *  Extracted from tpLoad.c
  */
-LOCAL tTemplate*
-findTemplate( tCC* pzTemplName );
+LOCAL tTemplate *
+findTemplate(char const * pzTemplName);
 
 LOCAL tSuccess
-findFile(tCC* pzFName, char* pzFullName, tCC** papSuffixList, tCC * pzReferrer);
-
-LOCAL tTemplate*
-loadTemplate(tCC* pzFileName, tCC * pzReferrer);
+findFile(char const * pzFName,
+         char * pzFullName,
+         char const * const * papSuffixList,
+         char const * pzReferrer);
 
 LOCAL void
-unloadTemplate( tTemplate* pT );
+append_source_name(char const * pz);
+
+LOCAL tTemplate *
+loadTemplate(char const * pzFileName, char const * referrer);
 
 LOCAL void
-cleanup( tTemplate* pTF );
+unloadTemplate(tTemplate* pT);
+
+LOCAL void
+cleanup(tTemplate* pTF);
 
 /*
  *  Extracted from tpParse.c
  */
 LOCAL tMacro*
-parseTemplate( tMacro* pM, tCC** ppzText );
+parseTemplate(tMacro* pM, char const ** ppzText);
 
 /*
  *  Extracted from tpProcess.c
  */
 LOCAL void
-generateBlock( tTemplate*   pT,
-               tMacro*      pMac,
-               tMacro*      pEnd );
+generateBlock(tTemplate * pT, tMacro * pMac, tMacro * pEnd);
 
 LOCAL tOutSpec *
 nextOutSpec(tOutSpec * pOS);
 
 LOCAL void
-processTemplate( tTemplate* pTF );
+processTemplate(tTemplate* pTF);
 
 LOCAL void
-closeOutput( ag_bool purge );
+closeOutput(ag_bool purge);
 
 #ifdef REDEF_LOCAL
 #  undef LOCAL
