@@ -1,10 +1,10 @@
-/*
- *  agTempl.c
- *  $Id: 3ba9563a24d217b0f13ef2d4466a3dae57a57e7e $
+
+/**
+ *  \file tpProcess.c
  *
  *  Parse and process the template data descriptions
  *
- * Time-stamp:        "2010-04-20 07:14:09 bkorb"
+ * Time-stamp:        "2010-07-16 17:35:09 bkorb"
  *
  * This file is part of AutoGen.
  * AutoGen Copyright (c) 1992-2010 by Bruce Korb - all rights reserved
@@ -27,25 +27,23 @@ static tFpStack fpRoot = { 0, NULL, NULL, NULL };
 
 /* = = = START-STATIC-FORWARD = = = */
 static void
-doStdoutTemplate( tTemplate* pTF );
+trace_macro(tTemplate * pT, tMacro * pMac);
 
 static void
-openOutFile(tOutSpec* pOutSpec);
+do_stdout_tpl(tTemplate * pTF);
+
+static void
+open_output(tOutSpec* pOutSpec);
 /* = = = END-STATIC-FORWARD = = = */
 
-/*
+/**
  *  Generate all the text within a block.  The caller must
  *  know the exact bounds of the block.  "pEnd" actually
  *  must point to the first entry that is *not* to be emitted.
  */
 LOCAL void
-generateBlock( tTemplate*   pT,
-               tMacro*      pMac,
-               tMacro*      pEnd )
+generateBlock(tTemplate * pT, tMacro * pMac, tMacro * pEnd)
 {
-    tSCC zFmt[] = "%-10s (%2X) in %s at line %d\n";
-    int  fc;
-
     /*
      *  Set up the processing context for this block of macros.
      *  It is used by the Guile callback routines and the exception
@@ -54,39 +52,57 @@ generateBlock( tTemplate*   pT,
     pCurTemplate = pT;
 
     while ((pMac != NULL) && (pMac < pEnd)) {
-        fc = pMac->funcCode;
+        teFuncType fc = pMac->funcCode;
         if (fc >= FUNC_CT)
             fc = FTYP_BOGUS;
 
-        if (OPT_VALUE_TRACE >= TRACE_EVERYTHING) {
-
-            fprintf( pfTrace, zFmt, apzFuncNames[ fc ], pMac->funcCode,
-                     pT->pzTplFile, pMac->lineNo );
-            if (pMac->ozText > 0) {
-                int   ct;
-                char* pz = pT->pzTemplText + pMac->ozText;
-                fputs( "  ", pfTrace );
-                for (ct=0; ct < 32; ct++) {
-                    char ch = *(pz++);
-                    if (ch == NUL)
-                        break;
-                    if (ch == '\n')
-                        break;
-                    putc( ch, pfTrace );
-                }
-                putc( '\n', pfTrace );
-            }
-        }
+        if (OPT_VALUE_TRACE >= TRACE_EVERYTHING)
+            trace_macro(pT, pMac);
 
         pCurMacro = pMac;
-        pMac = (*(apHdlrProc[ fc ]))( pT, pMac );
-        ag_scmStrings_free();
+        pMac = (*(apHdlrProc[ fc ]))(pT, pMac);
+        ag_scribble_free();
     }
 }
 
-
+/**
+ *  Print out information about the invocation of a macro
+ */
 static void
-doStdoutTemplate( tTemplate* pTF )
+trace_macro(tTemplate * pT, tMacro * pMac)
+{
+    static char const zFmt[] = "%-10s (%2X) in %s at line %d\n";
+
+    teFuncType fc = pMac->funcCode;
+    if (fc >= FUNC_CT)
+        fc = FTYP_BOGUS;
+
+    fprintf(pfTrace, zFmt, apzFuncNames[fc], pMac->funcCode,
+            pT->pzTplFile, pMac->lineNo);
+
+    if (pMac->ozText > 0) {
+        int   ct;
+        char* pz = pT->pzTemplText + pMac->ozText;
+        fputs("  ", pfTrace);
+        for (ct=0; ct < 32; ct++) {
+            char ch = *(pz++);
+            if (ch == NUL)
+                break;
+            if (ch == '\n')
+                break;
+            putc(ch, pfTrace);
+        }
+        putc('\n', pfTrace);
+    }
+}
+
+/**
+ *  The template output goes to stdout.  Perhaps because output
+ *  is for a CGI script.  In any case, this case must be handled
+ *  specially.
+ */
+static void
+do_stdout_tpl(tTemplate * pTF)
 {
     tSCC zNoSfx[] = "* NONE *";
     tSCC zBadR[]  = "%sBogus return from setjmp\n";
@@ -101,17 +117,17 @@ doStdoutTemplate( tTemplate* pTF )
 
     case PROBLEM:
         if (*pzOopsPrefix != NUL) {
-            fprintf( stdout, "%soutput was abandoned\n", pzOopsPrefix );
+            fprintf(stdout, "%soutput was abandoned\n", pzOopsPrefix);
             pzOopsPrefix = zNil;
         }
-        fclose( stdout );
+        fclose(stdout);
         return;
 
     default:
         fprintf(stdout, zBadR, pzOopsPrefix);
 
     case FAILURE:
-        exit( EXIT_FAILURE );
+        exit(EXIT_FAILURE);
     }
 
     pzCurSfx      = zNoSfx;
@@ -121,7 +137,7 @@ doStdoutTemplate( tTemplate* pTF )
     fpRoot.pzOutName = "stdout";
     fpRoot.flags  = FPF_NOUNLINK | FPF_STATIC_NM;
     if (OPT_VALUE_TRACE >= TRACE_EVERYTHING)
-        fputs( "Starting stdout template\n", pfTrace );
+        fputs("Starting stdout template\n", pfTrace);
 
     /*
      *  IF there is a CGI prefix for error messages,
@@ -129,31 +145,34 @@ doStdoutTemplate( tTemplate* pTF )
      *  the output will be clean for any error messages we have to emit.
      */
     if (*pzOopsPrefix == NUL)
-        generateBlock( pTF, pTF->aMacros, pTF->aMacros + pTF->macroCt );
+        generateBlock(pTF, pTF->aMacros, pTF->aMacros + pTF->macroCt);
 
     else {
         tSCC zCont[]  = "content-type:";
-        (void)ag_scm_out_push_new( SCM_UNDEFINED );
+        (void)ag_scm_out_push_new(SCM_UNDEFINED);
 
-        generateBlock( pTF, pTF->aMacros, pTF->aMacros + pTF->macroCt );
+        generateBlock(pTF, pTF->aMacros, pTF->aMacros + pTF->macroCt);
 
         /*
          *  Read back in the spooled output.  Make sure it starts with
          *  a content-type: prefix.  If not, we supply our own HTML prefix.
          */
-        res   = ag_scm_out_pop( SCM_BOOL_T );
-        pzRes = AG_SCM_CHARS( res );
+        res   = ag_scm_out_pop(SCM_BOOL_T);
+        pzRes = AG_SCM_CHARS(res);
 
-        if (strneqvcmp( pzRes, zCont, (int)sizeof(zCont) - 1) != 0)
-            fputs( "Content-Type: text/html\n\n", stdout );
+        if (strneqvcmp(pzRes, zCont, (int)sizeof(zCont) - 1) != 0)
+            fputs("Content-Type: text/html\n\n", stdout);
 
-        fwrite( pzRes, AG_SCM_STRLEN(res), (size_t)1, stdout );
+        fwrite(pzRes, AG_SCM_STRLEN(res), (size_t)1, stdout);
     }
 
-    fclose( stdout );
+    fclose(stdout);
 }
 
-
+/**
+ * pop the current output spec structure.  Deallocate it and the
+ * file name, too, if necessary.
+ */
 LOCAL tOutSpec *
 nextOutSpec(tOutSpec * pOS)
 {
@@ -168,7 +187,7 @@ nextOutSpec(tOutSpec * pOS)
 
 
 LOCAL void
-processTemplate( tTemplate* pTF )
+processTemplate(tTemplate* pTF)
 {
     forInfo.fi_depth = 0;
 
@@ -178,7 +197,7 @@ processTemplate( tTemplate* pTF )
      *  With output going to stdout, we don't try to remove output on errors.
      */
     if (pOutSpecList == NULL) {
-        doStdoutTemplate( pTF );
+        do_stdout_tpl(pTF);
         return;
     }
 
@@ -196,7 +215,7 @@ processTemplate( tTemplate* pTF )
         /*
          *  HOW was that we got here?
          */
-        switch (setjmp( fileAbort )) {
+        switch (setjmp(fileAbort)) {
         case SUCCESS:
             if (OPT_VALUE_TRACE >= TRACE_EVERYTHING) {
                 fprintf(pfTrace, "Starting %s template\n", pOS->zSuffix);
@@ -204,9 +223,9 @@ processTemplate( tTemplate* pTF )
             }
             /*
              *  Set the output file name buffer.
-             *  It may get switched inside openOutFile.
+             *  It may get switched inside open_output.
              */
-            openOutFile(pOS);
+            open_output(pOS);
             memcpy(&fpRoot, pCurFp, sizeof(fpRoot));
             AGFREE(pCurFp);
             pCurFp         = &fpRoot;
@@ -214,7 +233,7 @@ processTemplate( tTemplate* pTF )
             currDefCtx     = rootDefCtx;
             pCurFp->flags &= ~FPF_FREE;
             pCurFp->pPrev  = NULL;
-            generateBlock( pTF, pTF->aMacros, pTF->aMacros + pTF->macroCt );
+            generateBlock(pTF, pTF->aMacros, pTF->aMacros + pTF->macroCt);
 
             do  {
                 closeOutput(AG_FALSE);  /* keep output */
@@ -232,7 +251,7 @@ processTemplate( tTemplate* pTF )
             break;
 
         default:
-            fprintf( pfTrace, "%sBogus return from setjmp\n", pzOopsPrefix );
+            fprintf(pfTrace, "%sBogus return from setjmp\n", pzOopsPrefix);
             pzOopsPrefix = zNil;
             /* FALLTHROUGH */
 
@@ -259,12 +278,12 @@ processTemplate( tTemplate* pTF )
 
 
 LOCAL void
-closeOutput( ag_bool purge )
+closeOutput(ag_bool purge)
 {
     if ((pCurFp->flags & FPF_NOCHMOD) == 0)
-        removeWriteAccess( fileno( pCurFp->pFile ));
+        make_readonly(fileno(pCurFp->pFile));
 
-    fclose( pCurFp->pFile );
+    fclose(pCurFp->pFile);
 
     /*
      *  Only stdout and /dev/null are marked, "NOUNLINK"
@@ -275,15 +294,22 @@ closeOutput( ag_bool purge )
          *  file, then get rid of the output.
          */
         if (purge || ((pCurFp->flags & FPF_UNLINK) != 0))
-            unlink( pCurFp->pzOutName );
+            unlink(pCurFp->pzOutName);
 
         else {
             struct utimbuf tbuf;
 
-            tbuf.actime  = time( NULL );
+            tbuf.actime  = time(NULL);
             tbuf.modtime = outTime;
 
-            utime( pCurFp->pzOutName, &tbuf );
+            /*
+             *  The putative start time is one second earlier than the
+             *  earliest output file time, regardless of when that is.
+             */
+            if (outTime <= startTime)
+                startTime = outTime - 1;
+
+            utime(pCurFp->pzOutName, &tbuf);
         }
     }
 
@@ -291,7 +317,7 @@ closeOutput( ag_bool purge )
      *  Do not deallocate statically allocated names
      */
     if ((pCurFp->flags & FPF_STATIC_NM) == 0)
-        AGFREE( (void*)pCurFp->pzOutName );
+        AGFREE((void*)pCurFp->pzOutName);
 
     /*
      *  Do not deallocate the root entry.  It is not allocated!!
@@ -299,7 +325,7 @@ closeOutput( ag_bool purge )
     if ((pCurFp->flags & FPF_FREE) != 0) {
         tFpStack* p = pCurFp;
         pCurFp = p->pPrev;
-        AGFREE( (void*)p );
+        AGFREE((void*)p);
     }
 }
 
@@ -310,14 +336,13 @@ closeOutput( ag_bool purge )
  *  the definitions file.
  */
 static void
-openOutFile(tOutSpec* pOutSpec)
+open_output(tOutSpec* pOutSpec)
 {
     static char const write_mode[] = "w" FOPEN_BINARY_FLAG "+";
 
-    char const * pzDefFile = OPT_ARG( BASE_NAME );
-    char const * pzOutFile = NULL;
+    char const * out_file = NULL;
 
-    if (strcmp( pOutSpec->zSuffix, "null" ) == 0) {
+    if (strcmp(pOutSpec->zSuffix, "null") == 0) {
         static int const flags = FPF_NOUNLINK | FPF_NOCHMOD;
     null_open:
         open_output_file(zDevNull, sizeof(zDevNull)-1, write_mode, flags);
@@ -329,12 +354,12 @@ openOutFile(tOutSpec* pOutSpec)
      *  we will redirect the output to /dev/null and
      *  perform all the work.  There may be side effects.
      */
-    if (HAVE_OPT( SKIP_SUFFIX )) {
-        int     ct  = STACKCT_OPT(  SKIP_SUFFIX );
-        tCC**   ppz = STACKLST_OPT( SKIP_SUFFIX );
+    if (HAVE_OPT(SKIP_SUFFIX)) {
+        int     ct  = STACKCT_OPT(SKIP_SUFFIX);
+        tCC**   ppz = STACKLST_OPT(SKIP_SUFFIX);
 
         while (--ct >= 0) {
-            if (strcmp( pOutSpec->zSuffix, *ppz++ ) == 0)
+            if (strcmp(pOutSpec->zSuffix, *ppz++) == 0)
                 goto null_open;
         }
     }
@@ -343,21 +368,25 @@ openOutFile(tOutSpec* pOutSpec)
      *  Remove any suffixes in the last file name
      */
     {
-        char   z[ AG_PATH_MAX ];
-        tCC*   pS = strrchr(pzDefFile, '/');
+        static char const bad_fmt[] =
+            "Cannot format file name:  \"%s\", %s, %s";
+
+        char const * def_file = OPT_ARG(BASE_NAME);
+        char   z[AG_PATH_MAX];
+        tCC*   pS = strrchr(def_file, '/');
         char*  pE;
 
-        pS = (pS == NULL) ? pzDefFile : (pS + 1);
+        pS = (pS == NULL) ? def_file : (pS + 1);
 
         /*
          *  We allow users to specify a suffix with '-' and '_', but when
          *  stripping a suffix from the "base name", we do not recognize 'em.
          */
-        pE = strchr( pS, '.' );
+        pE = strchr(pS, '.');
         if (pE != NULL) {
             size_t len = (unsigned)(pE - pS);
             if (len >= sizeof(z))
-                AG_ABEND( "--base-name name is too long" );
+                AG_ABEND("--base-name name is too long");
 
             memcpy(z, pS, len);
             z[ pE - pS ] = NUL;
@@ -368,13 +397,13 @@ openOutFile(tOutSpec* pOutSpec)
          *  Now formulate the output file name in the buffer
          *  provided as the input argument.
          */
-        pzOutFile = aprf(pOutSpec->pzFileFmt, pS, pOutSpec->zSuffix);
-        if (pzOutFile == NULL)
-            AG_ABEND( aprf( "Cannot format file name:  ``%s''",
-                            pOutSpec->pzFileFmt ));
+        out_file = aprf(pOutSpec->pzFileFmt, pS, pOutSpec->zSuffix);
+        if (out_file == NULL)
+            AG_ABEND(aprf(bad_fmt, pOutSpec->pzFileFmt, pS, pOutSpec->zSuffix));
     }
 
-    open_output_file(pzOutFile, strlen(pzOutFile), write_mode, 0);
+    open_output_file(out_file, strlen(out_file), write_mode, 0);
+    free((void *)out_file);
 }
 /*
  * Local Variables:
