@@ -1,7 +1,7 @@
 /* -*- buffer-read-only: t -*- vi: set ro:
  *
  * Prototypes for getdefs
- * Generated Wed Mar  3 11:25:19 PST 2010
+ * Generated Sun Jul 25 09:16:21 PDT 2010
  */
 #ifndef GETDEFS_PROTO_H_GUARD
 #define GETDEFS_PROTO_H_GUARD 1
@@ -37,7 +37,7 @@ validateOptions( void );
  *  Extracted from getdefs.c
  */
 LOCAL char*
-loadFile( tCC* pzFname );
+loadFile(char const * pzFname);
 
 #ifdef REDEF_LOCAL
 #  undef LOCAL
