@@ -1,7 +1,7 @@
 #! /bin/sh
 
 ## mkgnudoc.sh --   create a native package
-## Time-stamp:      "2010-02-24 08:37:17 bkorb"
+## Time-stamp:      "2010-07-21 18:03:04 bkorb"
 ##
 ##  This file is part of AutoGen.
 ##  AutoGen Copyright (c) 1992-2010 by Bruce Korb - all rights reserved
@@ -18,10 +18,6 @@
 ##
 ##  You should have received a copy of the GNU General Public License along
 ##  with this program.  If not, see <http://www.gnu.org/licenses/>.
-## ---------------------------------------------------------------------
-## $Id$
-## ---------------------------------------------------------------------
-## Code:
 
 scriptdir=`dirname $0`
 test -f ${scriptdir}/pkg-env && . ${scriptdir}/pkg-env
@@ -122,6 +118,7 @@ autogen --base-name=${pkg} -T ${pkgsrcdir}/gnudoc.tpl - <<- _EODefs_
 	version = '${ver}';
 	package = '${pkg}';
 	_EODefs_
+test $? -ne 0 && exit 1
 
 rm -f TAG
 cd ..
